@@ -1,11 +1,5 @@
 #
-# $Id: Split.pm,v 0.34 2004/01/01 23:02:18 st.schubiger Exp $
-
-=head1 NAME
-
-Dir::Split - Split the files of a directory to subdirectories.
-
-=cut
+# $Id: Split.pm,v 0.35 2004/01/02 02:27:13 st.schubiger Exp $
 
 package Dir::Split;
 
@@ -18,7 +12,7 @@ use File::Copy 'cp';
 use File::Path;
 use File::Spec;
 
-our $VERSION = '0.34';
+our $VERSION = '0.35';
 
 our (# external refs
         $Source_dir_ref, # scl
@@ -54,25 +48,25 @@ our (# external refs
         $Suffix,
     );
 
-# opt presetting
 {
-    my ($PACKAGE, %Presets, %Var);
-
-    %Presets = (
-                 warn =>  {  dir  =>    "exists (d)\t",
-                             file =>    "exists (f)\t",
-                 },
+    my %Presets = (
+                    warn =>  {  dir  =>    "exists (d)\t",
+                                file =>    "exists (f)\t",
+                    },
     );
 
-    $PACKAGE = __PACKAGE__;
-
-    $Var{'warn'} = $PACKAGE.'::Warn';
+    {
     no strict 'refs';
 
-    $Var{'warn'}{'dir'} = $Presets{'warn'}{'dir'} unless $Var{'warn'}{'dir'};
-    $Var{'warn'}{'file'} = $Presets{'warn'}{'file'} unless $Var{'warn'}{'file'};
+    ${__PACKAGE__.'::Warn'}{'dir'} ||= $Presets{'warn'}{'dir'};
+    ${__PACKAGE__.'::Warn'}{'file'} ||= $Presets{'warn'}{'file'};
+    }
 }
 
+=head1 NAME
+
+Dir::Split - Split the files of a directory to subdirectories.
+
 =head1 SYNOPSIS
 
  use Dir::Split;
@@ -135,7 +129,7 @@ sub new {
       unless ref $Opt_ref eq 'HASH';
 
     my $class = ref ($pkg) || $pkg;
-    my $obj = Dir::Split::_tie_var ($Opt_ref);
+    my $obj = Dir::Split::_tie_var($Opt_ref);
 
     bless $obj, $class;
 }
@@ -214,24 +208,24 @@ sub split {
 #
 # _sanity_input()
 #
-# Ensure that the interface input passes sanity;
+# Ensures that the interface input passes sanity;
 # if not, croak.
 #
 
 sub _sanity_input {
-    my %err_msg = ( source_dir => 'No source dir specified.',
-                    target_dir => 'No target dir specified.',
-                    mode       => 'No mode specified.',
-                    verbosity  => 'No verbosity specified.',
-                    warn       => 'No warn mode specified.',
-                    override   => 'No override mode specified.',
-                    ident      => 'No subdir identifier specified.',
-                    sep        => 'No suffix separator specified.',
-                    case       => 'No suffix case mode specified.',
-                    file_limit => 'No file limit specified.',
-                    file_sort  => 'No file sort mode specified.',
-                    cont_num   => 'No continuation mode specified.',
-                    length     => 'No suffix length specified.'
+    my %err_msg = ( source_dir  =>    'No source dir specified.',
+                    target_dir  =>    'No target dir specified.',
+                    mode        =>    'No mode specified.',
+                    verbosity   =>    'No verbosity specified.',
+                    warn        =>    'No warn mode specified.',
+                    override    =>    'No override mode specified.',
+                    ident       =>    'No subdir identifier specified.',
+                    sep         =>    'No suffix separator specified.',
+                    case        =>    'No suffix case mode specified.',
+                    file_limit  =>    'No file limit specified.',
+                    file_sort   =>    'No file sort mode specified.',
+                    cont_num    =>    'No continuation mode specified.',
+                    length      =>    'No suffix length specified.'
     );
 
     no warnings;
@@ -295,7 +289,7 @@ sub _sanity_input {
 sub _gather_files {
     my $self = $_[0];
 
-    $self->_dir_read ($Source_dir_ref, $Files_ref);
+    $self->_dir_read($Source_dir_ref, $Files_ref);
     @$Files_ref = grep !-d File::Spec->catfile($$Source_dir_ref, $_), @$Files_ref;
 
     if ($$Mode_ref eq 'num' && ($$F_sort_ref eq '+' || $$F_sort_ref eq '-') ) {
@@ -323,7 +317,7 @@ sub _suffix_char {
             if ($$Case_ref eq 'upper') { $_ = uc ($_) }
             elsif ($$Case_ref eq 'lower') { $_ = lc ($_) }
         }
-        push (@{$$F_names_char_ref{$_}}, $file);
+        push @{$$F_names_char_ref{$_}}, $file;
     }
     undef @$Files_ref;
 }
@@ -345,7 +339,7 @@ sub _suffix_num {
 
     if ($$Cont_num_ref eq 'y') {
         my @dirs;
-        $self->_dir_read ($Target_dir_ref, \@dirs);
+        $self->_dir_read($Target_dir_ref, \@dirs);
         @dirs = grep -d File::Spec->catfile($$Target_dir_ref, $_), @dirs;
 
         my $sep = quotemeta $$Sep_ref;
@@ -397,11 +391,11 @@ sub _move_num {
     my $self = $_[0];
 
     for (; @$Files_ref; $$Suffix_ref++) {
-       $self->_mkpath ($$Suffix_ref);
+       $self->_mkpath($$Suffix_ref);
 
         for (my $i = 0; $i < $$F_limit_ref; $i++) {
             last unless my $file = shift @$Files_ref;
-            $self->_cp_unlink ($$F_names_case_ref{$file});
+            $self->_cp_unlink($$F_names_case_ref{$file});
         }
     }
 }
@@ -418,10 +412,10 @@ sub _move_char {
     my $self = $_[0];
 
     foreach (sort keys %$F_names_char_ref) {
-        $self->_mkpath ($_);
+        $self->_mkpath($_);
 
         while (@{$$F_names_char_ref{$_}}) {
-            $self->_cp_unlink (shift @{$$F_names_char_ref{$_}});
+            $self->_cp_unlink(shift @{$$F_names_char_ref{$_}});
         }
     }
 }
@@ -436,8 +430,9 @@ sub _move_char {
 sub _dir_read {
     shift; my ($dir_ref, $items_ref) = @_;
 
-    opendir D, $$dir_ref or croak qq~Could not open dir $$dir_ref for read-access: $!~;
-    @$items_ref = readdir D; splice (@$items_ref, 0, 2);
+    opendir D, $$dir_ref
+      or croak qq~Could not open dir $$dir_ref for read-access: $!~;
+    @$items_ref = readdir D; splice(@$items_ref, 0, 2);
     closedir D or croak qq~Could not close dir $$dir_ref: $!~;
 }
 
@@ -450,15 +445,17 @@ sub _dir_read {
 #
 
 sub _mkpath {
-    shift; my $Suffix = $_[0];
+    shift; my $suffix = $_[0];
 
-    $$Path_ref = File::Spec->catfile($$Target_dir_ref, "$$Ident_ref$$Sep_ref$Suffix");
+    $$Path_ref = File::Spec->catfile($$Target_dir_ref, "$$Ident_ref$$Sep_ref$suffix");
 
     if (-e $$Path_ref) {
-        warn "$Dir::Split::Warn{'dir'} $$Path_ref\n" if $$Warn_ref eq 'all' || $$Warn_ref eq 'dir';
+        warn "$Dir::Split::Warn{'dir'} $$Path_ref\n"
+          if $$Warn_ref eq 'all' || $$Warn_ref eq 'dir';
         return unless $$Override_ref eq 'all' || $$Override_ref eq 'dir';
     }
-    mkpath $$Path_ref, $$Verbose_ref or croak qq~Could not create subdir $$Path_ref: $!~;
+    mkpath $$Path_ref, $$Verbose_ref
+      or croak qq~Could not create subdir $$Path_ref: $!~;
 }
 
 #
@@ -475,7 +472,8 @@ sub _cp_unlink {
     $file = File::Spec->catfile($$Source_dir_ref, $file);
 
     if (-e $path_full) {
-        warn "$Dir::Split::Warn{'file'} $path_full \n" if $$Warn_ref eq 'all' || $$Warn_ref eq 'file';
+        warn "$Dir::Split::Warn{'file'} $path_full \n"
+          if $$Warn_ref eq 'all' || $$Warn_ref eq 'file';
         return unless $$Override_ref eq 'all' || $$Override_ref eq 'file';
     }
     cp $file, $path_full or
